#Author: Victor Slavutinsky

#Published by GPL license

bl_info={
	"name": "Panair",
	"description": "Export Panair datasheets in.imp format.",
	"author": "Victor Slavutinsky",
	"version": (0,1),
	"blender": (2,6,0),
	"api": 31236,
	"location": "File > Import-Export",
	"warning": "",
	"wiki_url": "",
	"tracker_url": "",
	"category": "Import-Export"
	}

if "bpy" in locals():
	import imp
	if "export_inp" in locals():
		imp.reload(export_inp)

import bpy

from bpy_extras.io_utils import ExportHelper
from bpy.props import FloatProperty, StringProperty, BoolProperty, EnumProperty

class ExportINP(bpy.types.Operator, ExportHelper):
	bl_idname="export_scene.export_inp"
	bl_label="Export .inp"
	bl_options={'PRESET'}
	filename_ext=".inp"

	fliter_glob=StringProperty(default="*.inp", options={'HIDDEN'})

	select_only=BoolProperty(name="Selection only", description="Export selected objects only", default=True)

	first_axis=EnumProperty(
		name="First Axis", 
		description="Where values at each row of resulted tables are going",
		items=(
			('X', "X First Axis", ""),
			('Y', "Y First Axis", ""),
			('Z', "Z First Axis", ""),
			('-X', "-X First Axis", ""),
			('-Y', "-Y First Axis", ""),
			('-Z', "-Z First Axis", "")
		),
		default='X'
		)

	second_axis=EnumProperty(
		name="Second axis", 
		description="Where values at colums of resulted tables are going",
		items=(
			('X', "X Second Axis", ""),
			('Y', "Y Second Axis", ""),
			('Z', "Z Second Axis", ""),
			('-X', "-X Second Axis", ""),
			('-Y', "-Y Second Axis", ""),
			('-Z', "-Z Second Axis", "")
		),
		default='Z'
		)

	first_priority=EnumProperty(
		name="First point priority", 
		description="Which axis has priority at first point search",
		items=(
			('First', "First Axis", ""),
			('Second', "Second Axis", "")
		),
		default='First'
		)

	wing_surface=BoolProperty(name="Two-sided wing", description="Two-sided wing surface", default=False)

	@classmethod
	def poll(cls, context):
		return context.active_object != None

	def execute(self, context):
		from . import export_inp
		export_inp.write_inp_file(
			context, 
			self.filepath, 
			select_only=self.select_only,
			first_axis=self.first_axis,
			second_axis=self.second_axis,
			first_priority=self.first_priority,
			wing_surface=self.wing_surface
		)
		return {'FINISHED'}

def menu_func_export(self, context):
	self.layout.operator(ExportINP.bl_idname, text="Panair input table (.inp)")

def register():
	bpy.utils.register_module(__name__)
	bpy.types.INFO_MT_file_export.append(menu_func_export)

def unregister():
	bpy.utils.unregister_module(__name__)
	bpy.types.INFO_MT_file_export.remove(menu_func_export)
	
if __name__=="__main__":
	register()
